@@ -1,7 +1,8 @@
 package Data::Hash::DotNotation;
-use strict; use warnings;
+use strict;
+use warnings;
 
-our $VERSION = '1.01';
+our $VERSION = '1.02';
 
 use Moose;
 use Carp;
@@ -10,10 +11,6 @@ use Carp;
 
 Data::Hash::DotNotation - Convenient representation for nested Hash structures
 
-=head1 VERSION
-
-1.01
-
 =head1 SYNOPSYS
 
     use Data::Hash::DotNotation;
@@ -29,6 +26,8 @@ Data::Hash::DotNotation - Convenient representation for nested Hash structures
 
     print $dn->get('score.contact');
 
+=head1 METHODS
+
 =cut
 
 has 'data' => (
@@ -36,12 +35,20 @@ has 'data' => (
     default => sub { {}; },
 );
 
+=head2 get
+
+=cut
+
 sub get {
     my $self = shift;
     my $name = shift or croak "No name given";
     return $self->_get($name);
 }
 
+=head2 set
+
+=cut
+
 sub set {
     my $self  = shift;
     my $name  = shift or croak 'No name given';
@@ -52,6 +59,10 @@ sub set {
     return $value;
 }
 
+=head2 key_exists
+
+=cut
+
 sub key_exists {
     my $self = shift;
     my $name = shift;
@@ -59,7 +70,6 @@ sub key_exists {
 
     my @parts = split(/\./, $name);
     my $node = pop @parts;
-    my $parent_node;
 
     while ($data and (my $section = shift @parts)) {
         if (ref $data->{$section} eq 'HASH') {
@@ -79,7 +89,6 @@ sub _get {
 
     my @parts = split(/\./, $name);
     my $node = pop @parts;
-    my $parent_node;
 
     while ($data and (my $section = shift @parts)) {
         if (ref $data->{$section} eq 'HASH') {
@@ -179,46 +188,6 @@ L<http://search.cpan.org/dist/Data-Hash-DotNotation/>
 
 =back
 
-=head1 LICENSE AND COPYRIGHT
-
-Copyright (C) 2015 binary.com
-
-This program is free software; you can redistribute it and/or modify it
-under the terms of the the Artistic License (2.0). You may obtain a
-copy of the full license at:
-
-L<http://www.perlfoundation.org/artistic_license_2_0>
-
-Any use, modification, and distribution of the Standard or Modified
-Versions is governed by this Artistic License. By using, modifying or
-distributing the Package, you accept this license. Do not use, modify,
-or distribute the Package, if you do not accept this license.
-
-If your Modified Version has been derived from a Modified Version made
-by someone other than you, you are nevertheless required to ensure that
-your Modified Version complies with the requirements of this license.
-
-This license does not grant you the right to use any trademark, service
-mark, tradename, or logo of the Copyright Holder.
-
-This license includes the non-exclusive, worldwide, free-of-charge
-patent license to make, have made, use, offer to sell, sell, import and
-otherwise transfer the Package with respect to any patent claims
-licensable by the Copyright Holder that are necessarily infringed by the
-Package. If you institute patent litigation (including a cross-claim or
-counterclaim) against any party alleging that the Package constitutes
-direct or contributory patent infringement, then this Artistic License
-to you shall terminate on the date that such litigation is filed.
-
-Disclaimer of Warranty: THE PACKAGE IS PROVIDED BY THE COPYRIGHT HOLDER
-AND CONTRIBUTORS "AS IS' AND WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES.
-THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-PURPOSE, OR NON-INFRINGEMENT ARE DISCLAIMED TO THE EXTENT PERMITTED BY
-YOUR LOCAL LAW. UNLESS REQUIRED BY LAW, NO COPYRIGHT HOLDER OR
-CONTRIBUTOR WILL BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, OR
-CONSEQUENTIAL DAMAGES ARISING IN ANY WAY OUT OF THE USE OF THE PACKAGE,
-EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-
 =cut
 
 1;
